@@ -1,7 +1,7 @@
 /* -*- indent-tabs-mode: t; tab-width: 8; c-basic-offset: 8; -*- */
 
 /* Copyright (c) 2004 - 2006 Derek Foreman, Ben Jansens
-   Copyright (c) 2006 - 2010 Thomas Schmitt <scdbackup@gmx.net>
+   Copyright (c) 2006 - 2011 Thomas Schmitt <scdbackup@gmx.net>
    Provided under GPL version 2 or later.
 */
 
@@ -177,6 +177,8 @@ void burn_finish(void)
 
 	sg_shutdown(0);
 
+	burn_drive_clear_whitelist();
+
 	burn_running = 0;
 }
 
@@ -352,7 +354,7 @@ char *burn_util_thread_id(pid_t pid, pthread_t tid, char text[80])
 
 	sprintf(text, "[%lu,", (unsigned long int) getpid());
 	l= strlen(text);
-	for(i= 0; i < sizeof(pthread_t) && 2 * i < 80 - l - 3; i++)
+	for(i= 0; i < ((int) sizeof(pthread_t)) && 2 * i < 80 - l - 3; i++)
 		sprintf(text + l + 2 * i,
 			 "%2.2X", ((unsigned char *) &tid)[i]);
 
@@ -580,3 +582,18 @@ void burn_allow_drive_role_4(int allowed)
 {
 	burn_drive_role_4_allowed = (allowed & 0xf);
 }
+
+
+/* ts B10606 */
+void *burn_alloc_mem(size_t size, size_t count, int flag)
+{
+	void *pt;
+
+	pt = calloc(size, count);
+	if(pt == NULL)
+		libdax_msgs_submit(libdax_messenger, -1, 0x00000003,
+				LIBDAX_MSGS_SEV_FATAL, LIBDAX_MSGS_PRIO_HIGH,
+				"Out of virtual memory", 0, 0);
+	return pt;
+}
+
