@@ -142,6 +142,9 @@ Send feedback to libburn-hackers@pykix.org .
 #define Libburn_is_on_solariS 1
 #endif
 
+/* Proposal by Rocky Bernstein to avoid macro clashes with cdio_config.h */
+#define __CDIO_CONFIG_H__ 1
+
 #include <cdio/cdio.h>
 #include <cdio/logging.h>
 #include <cdio/mmc.h>
@@ -454,7 +457,7 @@ int sg_give_next_adr(burn_drive_enumerator_t *idx,
 
 	ret = burn_drive_resolve_link(adr, path, &recursion_count, 2);
         if(ret > 0 && (ssize_t) strlen(path) < adr_size)
-		strcpy(path, adr);
+		strcpy(adr, path);
 	ret = (ret >= 0);
 ex:
 	BURN_FREE_MEM(path);
@@ -594,10 +597,8 @@ ex:;
 */
 int sg_release(struct burn_drive *d)
 {
-	if (d->p_cdio == NULL) {
-		burn_print(1, "release an ungrabbed drive.  die\n");
+	if (d->p_cdio == NULL)
 		return 0;
-	}
 	sg_close_drive(d);
 	return 0;
 }
@@ -614,7 +615,7 @@ int sg_release(struct burn_drive *d)
 */
 int sg_issue_command(struct burn_drive *d, struct command *c)
 {
-	int sense_valid = 0, i, timeout_ms;
+	int sense_valid = 0, i, timeout_ms, sense_len;
 	int key = 0, asc = 0, ascq = 0, done = 0;
 	time_t start_time;
         driver_return_code_t i_status;
@@ -623,7 +624,7 @@ int sg_issue_command(struct burn_drive *d, struct command *c)
 	mmc_cdb_t cdb = {{0, }};
 	cdio_mmc_direction_t e_direction;
 	CdIo_t *p_cdio;
-	unsigned char *sense_pt = NULL;
+	cdio_mmc_request_sense_t *sense_pt = NULL;
 
 	c->error = 0;
 	if (d->p_cdio == NULL) {
@@ -666,7 +667,7 @@ int sg_issue_command(struct burn_drive *d, struct command *c)
 				 	dxfer_len, c->page->data);
 		sense_valid = mmc_last_cmd_sense(p_cdio, &sense_pt);
 		if (sense_valid >= 18) {
-			memcpy(c->sense, sense_pt,
+			memcpy(c->sense, (unsigned char *) sense_pt,
 				(size_t) sense_valid >= sizeof(c->sense) ?
 				sizeof(c->sense) : (size_t) sense_valid );
 			spc_decode_sense(c->sense, 0, &key, &asc, &ascq);
@@ -704,11 +705,12 @@ int sg_issue_command(struct burn_drive *d, struct command *c)
 				done = 1;
 			}
 		} 
-		if (i_status != 0 || (key || asc || ascq)) {
-			done = scsi_eval_cmd_outcome(d, c, fp,  c->sense, 18,
+		if (key || asc || ascq)
+			sense_len = 18;
+		else
+			sense_len = 0;
+		done = scsi_eval_cmd_outcome(d, c, fp,  c->sense, sense_len,
 					0, start_time, timeout_ms, i, 2);
-		} else
-			done = 1;
 
 	} /* end of retry-loop */
 
@@ -881,7 +883,7 @@ int burn_os_stdio_capacity(char *path, off_t *bytes)
 
 	/* GNU/Linux specific determination of block device size */
 	} else if(S_ISBLK(stbuf.st_mode)) {
-		int open_mode = O_RDONLY, fd, ret;
+		int open_mode = O_RDONLY, fd;
 		long blocks;
 
 		blocks = *bytes / 512;
@@ -899,7 +901,7 @@ int burn_os_stdio_capacity(char *path, off_t *bytes)
 #ifdef Libburn_is_on_freebsD
 
 	} else if(S_ISCHR(stbuf.st_mode)) {
-		int fd, ret;
+		int fd;
 
 		fd = open(path, O_RDONLY);
 		if (fd == -1)
