@@ -185,6 +185,8 @@ static int linux_sg_enumerate_debug = 0;
    E.g.: "/dev/sg%d"
    sr%d is supposed to map only CD-ROM style devices. Additionally a test
    with ioctl(CDROM_DRIVE_STATUS) is made to assert that it is such a drive,
+   If no such assertion is made, then this adapter performs INQUIRE and
+   looks for first reply byte 0x05.
 
    This initial setting may be overridden in sg_select_device_family() by 
    settings made via burn_preset_device_open().
@@ -252,9 +254,13 @@ int burn_drive_is_banned(char *device_address);
 /* ------------------------------------------------------------------------ */
 
 
-static void enumerate_common(char *fname, int bus_no, int host_no,
+static void enumerate_common(char *fname, int fd_in, int bus_no, int host_no,
 			     int channel_no, int target_no, int lun_no);
 
+static int sg_obtain_scsi_adr_fd(char *path, int fd_in,
+				 int *bus_no, int *host_no, int *channel_no,
+				 int *target_no, int *lun_no);
+
 
 /* ts A60813 : storage objects are in libburn/init.c
    whether to use O_EXCL with open(2) of devices
@@ -372,10 +378,48 @@ static int sg_exchange_scd_for_sr(char *fname, int flag)
 }
 
 
+/* ts B11110 */
+/* This is an early stage version of scsi_log_cmd.
+   >>> It will become obsolete when the /tmp file handler is moved into
+   >>> scsi_log_command().
+*/
+static int sgio_log_cmd(unsigned char *cmd, int cmd_len, FILE *fp_in, int flag)
+{
+	FILE *fp = fp_in;
+	int ret;
+
+	/* >>> ts B11110 : move this into scsi_log_command() */
+	if (fp == NULL && (burn_sg_log_scsi & 1)) {
+		fp= fopen("/tmp/libburn_sg_command_log", "a");
+		fprintf(fp, "\n=========================================\n");
+	}
+
+	ret = scsi_log_command(cmd, cmd_len, NO_TRANSFER, NULL, 0, fp, flag);
+	if (fp_in == NULL && fp != NULL)
+		fclose(fp);
+	return ret;
+}
+
+
+/* ts B11110 */
+static int sgio_log_reply(unsigned char *opcode, int data_dir,
+                          unsigned char *data, int dxfer_len,
+                          void *fp_in, unsigned char sense[18],
+                          int sense_len, int duration, int flag)
+{
+	int ret;
+
+	ret = scsi_log_reply(opcode, data_dir, data, dxfer_len, fp_in,
+	                     sense, sense_len, duration, flag);
+	return 1;
+}
+
+
 static int sgio_test(int fd)
 {
 	unsigned char test_ops[] = { 0, 0, 0, 0, 0, 0 };
 	sg_io_hdr_t s;
+	int ret;
 
 	memset(&s, 0, sizeof(sg_io_hdr_t));
 	s.interface_id = 'S';
@@ -383,7 +427,91 @@ static int sgio_test(int fd)
 	s.cmd_len = 6;
 	s.cmdp = test_ops;
 	s.timeout = 12345;
-	return ioctl(fd, SG_IO, &s);
+
+	sgio_log_cmd(s.cmdp, s.cmd_len, NULL, 0);
+
+	ret= ioctl(fd, SG_IO, &s);
+
+	sgio_log_reply(s.cmdp, NO_TRANSFER, NULL, 0,
+                       NULL, s.sbp, s.sb_len_wr, s.duration, 0);
+	return ret;
+}
+
+
+static int sgio_inquiry_cd_drive(int fd, char *fname)
+{
+	unsigned char test_ops[] = { 0x12, 0, 0, 0, 36, 0 };
+	sg_io_hdr_t s;
+	struct buffer *buf = NULL;
+	unsigned char *sense = NULL;
+	char *msg = NULL, *msg_pt;
+	int ret = 0, i;
+
+	BURN_ALLOC_MEM(buf, struct buffer, 1);
+	BURN_ALLOC_MEM(sense, unsigned char, 128);
+	BURN_ALLOC_MEM(msg, char, strlen(fname) + 1024);
+
+	memset(&s, 0, sizeof(sg_io_hdr_t));
+	s.interface_id = 'S';
+	s.dxfer_direction = SG_DXFER_FROM_DEV;
+	s.cmd_len = 6;
+	s.cmdp = test_ops;
+	s.mx_sb_len = 32;
+	s.sbp = sense;
+	s.timeout = 30000;
+	s.dxferp = buf;
+	s.dxfer_len = 36;
+	s.usr_ptr = NULL;
+
+	sgio_log_cmd(s.cmdp, s.cmd_len, NULL, 0);
+
+	ret = ioctl(fd, SG_IO, &s);
+	if (ret == -1) {
+		sprintf(msg,
+			 "INQUIRY on '%s' : ioctl(SG_IO) failed , errno= %d",
+			 fname, errno);
+		libdax_msgs_submit(libdax_messenger, -1, 0x00000002,
+			LIBDAX_MSGS_SEV_DEBUG, LIBDAX_MSGS_PRIO_HIGH,
+			msg, 0, 0);
+		goto ex;
+	}
+
+	sgio_log_reply(s.cmdp, FROM_DRIVE, buf->data, s.dxfer_len,
+                       NULL, s.sbp, s.sb_len_wr, s.duration, 0);
+
+	if (s.sb_len_wr > 0 || s.host_status != Libburn_sg_host_oK ||
+	    s.driver_status != Libburn_sg_driver_oK) {
+		sprintf(msg, "INQUIRY failed on '%s' : host_status= %hd , driver_status= %hd", fname, s.host_status, s.driver_status);
+		if (s.sb_len_wr > 0) {
+			sprintf(msg + strlen(msg), " , sense data=");
+			msg_pt = msg + strlen(msg);
+			for (i = 0 ; i < s.sb_len_wr; i++)
+				sprintf(msg_pt + i * 3, " %2.2X", s.sbp[i]);
+		}
+		libdax_msgs_submit(libdax_messenger, -1, 0x00000002,
+			LIBDAX_MSGS_SEV_DEBUG, LIBDAX_MSGS_PRIO_HIGH,
+			msg, 0, 0);
+		ret = -1;
+		goto ex;
+	}
+	ret = 0;
+	if (buf->data[0] == 0x5) {
+		/* Peripheral qualifier 0, device type 0x5 = CD/DVD device.
+		   SPC-3 tables 82 and 83  */
+		ret = 1;
+	} else {
+		sprintf(msg, "INQUIRY on '%s' : byte 0 = 0x%2.2X",
+			 fname, buf->data[0]);
+		libdax_msgs_submit(libdax_messenger, -1, 0x00000002,
+			LIBDAX_MSGS_SEV_DEBUG, LIBDAX_MSGS_PRIO_HIGH,
+			msg, 0, 0);
+	}
+
+ex:;
+	BURN_FREE_MEM(msg);
+	BURN_FREE_MEM(sense);
+	BURN_FREE_MEM(buf);
+	return ret;
 }
 
 
@@ -757,12 +885,15 @@ failed:;
 
 
 /* ts A80731 */
-static int is_ata_drive(char *fname)
+static int is_ata_drive(char *fname, int fd_in)
 {
 	int fd;
 	struct hd_driveid tm;
 
-	fd = sg_open_drive_fd(fname, 1);
+	if (fd_in >= 0)
+		fd = fd_in;
+	else
+		fd = sg_open_drive_fd(fname, 1);
 	if (fd == -1) {
 		if (linux_ata_enumerate_verbous)
 			fprintf(stderr,"open failed, errno=%d  '%s'\n",
@@ -777,7 +908,8 @@ static int is_ata_drive(char *fname)
 	if (!(tm.config & 0x8000) || (tm.config & 0x4000)) {
 		if (linux_ata_enumerate_verbous)
 			fprintf(stderr, "not marked as ATAPI\n");
-		sg_close_drive_fd(fname, -1, &fd, 0);
+		if (fd_in < 0)
+			sg_close_drive_fd(fname, -1, &fd, 0);
 		return 0;
 	}
 
@@ -788,9 +920,12 @@ static int is_ata_drive(char *fname)
 		  fprintf(stderr,
 			 "FATAL: sgio_test() failed: errno=%d  '%s'\n",
 			 errno, strerror(errno));
-		sg_close_drive_fd(fname, -1, &fd, 0);
+		if (fd_in < 0)
+			sg_close_drive_fd(fname, -1, &fd, 0);
 		return 0;
 	}
+	if (fd_in >= 0)
+		return 1;
 	if (sg_close_drive_fd(fname, -1, &fd, 1) <= 0) {
 		if (linux_ata_enumerate_verbous)
 			fprintf(stderr,
@@ -802,10 +937,10 @@ static int is_ata_drive(char *fname)
 }
 
 
-static int is_scsi_drive(char *fname, int *bus_no, int *host_no,
+static int is_scsi_drive(char *fname, int fd_in, int *bus_no, int *host_no,
 			 int *channel_no, int *target_no, int *lun_no)
 {
-	int fd, sid_ret = 0, ret;
+	int fd = -1, sid_ret = 0, ret, fail_sev_sorry = 0;
 	struct sg_scsi_id sid;
 	int *sibling_fds = NULL, sibling_count= 0;
 	typedef char burn_sg_sibling_fname[BURN_OS_SG_MAX_NAMELEN];
@@ -815,14 +950,16 @@ static int is_scsi_drive(char *fname, int *bus_no, int *host_no,
 	BURN_ALLOC_MEM(sibling_fnames, burn_sg_sibling_fname,
 			BURN_OS_SG_MAX_SIBLINGS);
 
-	fd = sg_open_drive_fd(fname, 1);
+	if (fd_in >= 0)
+		fd = fd_in;
+	else
+		fd = sg_open_drive_fd(fname, 1);
 	if (fd == -1) {
 		if (linux_sg_enumerate_debug)
 			fprintf(stderr, "open failed, errno=%d  '%s'\n",
 				errno, strerror(errno));
 		{ret = 0; goto ex;}
 	}
-
 	sid_ret = ioctl(fd, SG_GET_SCSI_ID, &sid);
 	if (sid_ret == -1) {
 		sid.scsi_id = -1; /* mark SCSI address as invalid */
@@ -837,7 +974,6 @@ static int is_scsi_drive(char *fname, int *bus_no, int *host_no,
 				 "FATAL: sgio_test() failed: errno=%d  '%s'",
 				errno, strerror(errno));
 
-			sg_close_drive_fd(fname, -1, &fd, 0);
 			{ret = 0; goto ex;}
 		}
 
@@ -857,20 +993,22 @@ static int is_scsi_drive(char *fname, int *bus_no, int *host_no,
 
 	}
 
+	if (sid_ret == -1) {
+		/* ts B11109 : Try device type from INQUIRY byte 0 */
+		if (sgio_inquiry_cd_drive(fd, fname) == 1) {
+			sid_ret = 0;
+			sid.scsi_type = TYPE_ROM;
+		}
+	}
+
+
 #ifdef SCSI_IOCTL_GET_BUS_NUMBER
 	/* Hearsay A61005 */
 	if (ioctl(fd, SCSI_IOCTL_GET_BUS_NUMBER, bus_no) == -1)
 		*bus_no = -1;
 #endif
 
-	if (sg_close_drive_fd(fname, -1, &fd, 
-					sid.scsi_type == TYPE_ROM ) <= 0) {
-		if (linux_sg_enumerate_debug)
-			fprintf(stderr,
-				"cannot close properly, errno=%d  '%s'\n",
-				errno, strerror(errno)); 
-		{ret = 0; goto ex;}
-	}
+	fail_sev_sorry = (sid.scsi_type == TYPE_ROM);
 	if ( (sid_ret == -1 || sid.scsi_type != TYPE_ROM)
 	     && !linux_sg_accept_any_type) {
 		if (linux_sg_enumerate_debug)
@@ -881,7 +1019,8 @@ static int is_scsi_drive(char *fname, int *bus_no, int *host_no,
 
 	if (sid_ret == -1 || sid.scsi_id < 0) {
 		/* ts A61211 : employ a more general ioctl */
-		ret = sg_obtain_scsi_adr(fname, bus_no, host_no,
+		/* ts B11001 : re-use fd */
+		ret = sg_obtain_scsi_adr_fd(fname, fd, bus_no, host_no,
 					   channel_no, target_no, lun_no);
 		if (ret>0) {
 			sid.host_no = *host_no;
@@ -891,7 +1030,7 @@ static int is_scsi_drive(char *fname, int *bus_no, int *host_no,
 		} else {
 			if (linux_sg_enumerate_debug)
 				fprintf(stderr,
-					"sg_obtain_scsi_adr() failed\n");
+					"sg_obtain_scsi_adr_fd() failed\n");
 			{ret = 0; goto ex;}
 		}
 	}
@@ -925,18 +1064,42 @@ static int is_scsi_drive(char *fname, int *bus_no, int *host_no,
 	*lun_no= sid.lun;
 	ret = 1;
 ex:;
+	if (fd_in < 0 && fd >= 0) {
+		if (sg_close_drive_fd(fname, -1, &fd, fail_sev_sorry) <= 0) {
+			if (linux_sg_enumerate_debug)
+				fprintf(stderr,
+				"cannot close properly, errno=%d  '%s'\n",
+				errno, strerror(errno)); 
+			if (ret > 0)
+				ret = 0;
+		}
+	}
 	BURN_FREE_MEM(sibling_fds);
 	BURN_FREE_MEM(sibling_fnames);
 	return ret;
 }	
 
 
+static int sg_open_for_enumeration(char *fname, int flag)
+{
+	int fd;
+
+	fd = sg_open_drive_fd(fname, 1);
+	if (fd < 0) {
+		if (linux_sg_enumerate_debug || linux_ata_enumerate_verbous)
+			fprintf(stderr, "open failed, errno=%d  '%s'\n",
+				errno, strerror(errno));
+		return -1;
+	}
+	return fd;
+}
+
+
 /** Speciality of GNU/Linux: detect non-SCSI ATAPI (EIDE) which will from
    then on used used via generic SCSI as is done with (emulated) SCSI drives */ 
 static void ata_enumerate(void)
 {
-	int ret;
-	int i;
+	int ret, i, fd = -1;
 	char fname[10];
 
 	if (linux_ata_enumerate_verbous)
@@ -957,14 +1120,17 @@ static void ata_enumerate(void)
 				fprintf(stderr, "not in whitelist\n");
 	continue;
 		}
-		ret = is_ata_drive(fname);
+		fd = sg_open_for_enumeration(fname, 0);
+		if (fd < 0)
+	continue;
+		ret = is_ata_drive(fname, fd);
 		if (ret < 0)
 	break;
 		if (ret == 0)
 	continue;
 		if (linux_ata_enumerate_verbous)
 		  fprintf(stderr, "accepting as drive without SCSI address\n");
-		enumerate_common(fname, -1, -1, -1, -1, -1);
+		enumerate_common(fname, fd, -1, -1, -1, -1, -1);
 	}
 }
 
@@ -972,7 +1138,7 @@ static void ata_enumerate(void)
 /** Detects (probably emulated) SCSI drives */
 static void sg_enumerate(void)
 {
-	int i, ret;
+	int i, ret, fd = -1;
 	int bus_no= -1, host_no= -1, channel_no= -1, target_no= -1, lun_no= -1;
 	char fname[17];
 
@@ -1000,8 +1166,11 @@ static void sg_enumerate(void)
 			  fprintf(stderr, "not in whitelist\n"); 
 	continue;
 		}
+		fd = sg_open_for_enumeration(fname, 0);
+		if (fd < 0)
+	continue;
 
-		ret = is_scsi_drive(fname, &bus_no, &host_no, &channel_no,
+		ret = is_scsi_drive(fname, fd, &bus_no, &host_no, &channel_no,
 							&target_no, &lun_no);
 		if (ret < 0)
 	break;
@@ -1010,7 +1179,7 @@ static void sg_enumerate(void)
 		if (linux_sg_enumerate_debug)
 		  fprintf(stderr, "accepting as SCSI %d,%d,%d,%d bus=%d\n",
 			  host_no, channel_no, target_no, lun_no, bus_no);
-		enumerate_common(fname, bus_no, host_no, channel_no, 
+		enumerate_common(fname, fd, bus_no, host_no, channel_no, 
 				target_no, lun_no);
 
 	}
@@ -1059,7 +1228,7 @@ static int fname_drive_is_listed(char *fname, int flag)
 */
 static int fname_enumerate(char *fname, int flag)
 {
-	int is_ata= 0, is_scsi= 0, ret;
+	int is_ata= 0, is_scsi= 0, ret, fd = -1;
 	int bus_no= -1, host_no= -1, channel_no= -1, target_no= -1, lun_no= -1;
 	char *msg = NULL;
 	struct stat stbuf;
@@ -1077,13 +1246,16 @@ static int fname_enumerate(char *fname, int flag)
 			  msg, 0, 0);
 		{ret = -1; goto ex;}
 	}
-	
-	is_ata = is_ata_drive(fname);
+
+	fd = sg_open_for_enumeration(fname, 0);
+	if (fd < 0)
+		{ret = 0; goto ex;}
+	is_ata = is_ata_drive(fname, fd);
 	if (is_ata < 0)
 		{ret = -1; goto ex;}
 	if (!is_ata)
-		is_scsi = is_scsi_drive(fname, &bus_no, &host_no, &channel_no,
-					&target_no, &lun_no);
+		is_scsi = is_scsi_drive(fname, fd, &bus_no, &host_no,
+					&channel_no, &target_no, &lun_no);
 	if (is_scsi < 0)
 		{ret = -1; goto ex;}
 	if (is_ata == 0 && is_scsi == 0)
@@ -1093,7 +1265,8 @@ static int fname_enumerate(char *fname, int flag)
 		  fprintf(stderr,
 			"(single) accepting as SCSI %d,%d,%d,%d bus=%d\n",
 			host_no, channel_no, target_no, lun_no, bus_no);
-	enumerate_common(fname, bus_no, host_no, channel_no, 
+
+	enumerate_common(fname, fd, bus_no, host_no, channel_no, 
 				target_no, lun_no);
 	ret = 1;
 ex:;
@@ -1217,6 +1390,9 @@ static int add_proc_info_drives(int flag)
 	int ret, list_count, count = 0, i;
 	char **list= NULL;
 
+	if (burn_sg_use_family != 0)
+		return(1); /* Looking only for sr resp. scd resp. sg */
+
 	ret = proc_sys_dev_cdrom_info(&list, &list_count, 0);
 	if (ret <= 0)
 		return ret;
@@ -1246,7 +1422,7 @@ static int add_proc_info_drives(int flag)
 */
 /* ts A60923 - A61005 : introduced new SCSI parameters */
 /* ts A61021 : moved non os-specific code to spc,sbc,mmc,drive */
-static void enumerate_common(char *fname, int bus_no, int host_no,
+static void enumerate_common(char *fname, int fd_in, int bus_no, int host_no,
 			     int channel_no, int target_no, int lun_no)
 {
 	int ret, i;
@@ -1278,8 +1454,12 @@ static void enumerate_common(char *fname, int bus_no, int host_no,
 	out.release = sg_release;
 	out.drive_is_open= sg_drive_is_open;
 	out.issue_command = sg_issue_command;
+	if (fd_in >= 0)
+		out.fd = fd_in;
 
-	/* Finally register drive and inquire drive information */
+	/* Finally register drive and inquire drive information.
+	   out is an invalid copy afterwards. Do not use it for anything.
+	 */
 	burn_drive_finish_enum(&out);
 }
 
@@ -1533,6 +1713,12 @@ int sg_grab(struct burn_drive *d)
 	if(! burn_drive_is_open(d)) {
 		char msg[120];
 
+/* >>> SINGLE_OPEN : This case should be impossible now, since enumeration
+                     transfers the fd from scanning to drive.
+                     So if close-wait-open is desired, then it has to
+                     be done unconditionally.
+*/
+
 #ifndef Libburn_udev_wait_useC
 #define Libburn_udev_wait_useC 100000
 #endif
@@ -1577,7 +1763,6 @@ try_open:;
 			if(ret <= 0)
 				goto drive_is_in_use;
 		}
-
 		fd = open(d->devname, open_mode);
 		os_errno = errno;
 
@@ -1661,10 +1846,8 @@ int sg_release(struct burn_drive *d)
 	if (mmc_function_spy(d, "sg_release") <= 0)
 		return 0;
 
-	if (d->fd < 1) {
-		burn_print(1, "release an ungrabbed drive.  die\n");
+	if (d->fd < 1)
 		return 0;
-	}
 
 	/* ts A60821
    	<<< debug: for tracing calls which might use open drive fds */
@@ -1700,6 +1883,8 @@ int sg_issue_command(struct burn_drive *d, struct command *c)
 		d->fd, d->released);
 	mmc_function_spy(NULL, msg);
 
+	/* >>> ts B11110 : move this into scsi_log_cmd() together with the
+	                    static fp */
 	/* ts A61030 */
 	if (burn_sg_log_scsi & 1) {
 		if (fp == NULL) {
@@ -1820,12 +2005,13 @@ ex:;
 }
 
 
-/* ts A60922 */
+/* ts B11001 : outsourced from non-static sg_obtain_scsi_adr() */
 /** Tries to obtain SCSI address parameters.
     @return  1 is success , 0 is failure
 */
-int sg_obtain_scsi_adr(char *path, int *bus_no, int *host_no, int *channel_no,
-                       int *target_no, int *lun_no)
+static int sg_obtain_scsi_adr_fd(char *path, int fd_in,
+				 int *bus_no, int *host_no, int *channel_no,
+				 int *target_no, int *lun_no)
 {
 	int fd, ret, l, open_mode = O_RDONLY;
 	struct my_scsi_idlun {
@@ -1853,7 +2039,10 @@ int sg_obtain_scsi_adr(char *path, int *bus_no, int *host_no, int *channel_no,
 		   SuSE 9.0 (kernel 2.4) and SuSE 9.3 (kernel 2.6) */
 		/* so skip it for now */;
 	}
-	fd = open(path, open_mode);
+	if (fd_in >= 0)
+		fd = fd_in;
+	else
+		fd = open(path, open_mode);
 	if(fd < 0)
 		return 0;
 	sg_fcntl_lock(&fd, path, F_RDLCK, 0);
@@ -1869,7 +2058,8 @@ int sg_obtain_scsi_adr(char *path, int *bus_no, int *host_no, int *channel_no,
 	/* http://www.tldp.org/HOWTO/SCSI-Generic-HOWTO/scsi_g_idlun.html */
 	ret = ioctl(fd, SCSI_IOCTL_GET_IDLUN, &idlun);
 
-	sg_close_drive_fd(path, -1, &fd, 0);
+	if (fd_in < 0)
+		sg_close_drive_fd(path, -1, &fd, 0);
 	if (ret == -1)
 		return(0);
 	*host_no= (idlun.x>>24)&255;
@@ -1886,6 +2076,18 @@ int sg_obtain_scsi_adr(char *path, int *bus_no, int *host_no, int *channel_no,
 }
 
 
+/* ts A60922 */
+/** Tries to obtain SCSI address parameters.
+    @return  1 is success , 0 is failure
+*/
+int sg_obtain_scsi_adr(char *path, int *bus_no, int *host_no, int *channel_no,
+                       int *target_no, int *lun_no)
+{
+	return sg_obtain_scsi_adr_fd(path, -1, bus_no, host_no, channel_no,
+					 target_no, lun_no);
+}
+
+
 /* ts A60922 ticket 33 : called from drive.c */
 /** Tells wether a text is a persistent address as listed by the enumeration
     functions.
