@@ -332,7 +332,7 @@ int isoburn_is_intermediate_dvd_rw(struct burn_drive *d, int flag)
 }
 
 
-/** Examines the media and sets appropriate emulation if needed.
+/** Examines the medium and sets appropriate emulation if needed.
     @param flag bit0= pretent blank on overwriteable media
                 bit3= if the drive reports a -ROM profile then try to read 
                       table of content by scanning for ISO image headers.
@@ -366,7 +366,7 @@ static int isoburn_welcome_media(struct isoburn **o, struct burn_drive *d,
  if(ret<=0)
    profile= 0x00;
  ret= burn_disc_get_multi_caps(d, BURN_WRITE_NONE, &caps, 0);
- if(ret<0) /* == 0 is read-only media, but it is too early to reject it here */
+ if(ret<0) /*== 0 is read-only medium, but it is too early to reject it here */
    goto ex;
  if(ret==0 || (flag & 128))
    readonly= 1;
@@ -428,13 +428,13 @@ static int isoburn_welcome_media(struct isoburn **o, struct burn_drive *d,
      */
      (*o)->fabricated_disc_status= BURN_DISC_FULL;
 
-     /* This might be overwriteable media in a -ROM drive.
+     /* This might be an overwriteable medium in a -ROM drive.
         Pitfall:
         Multi-session media which bear a xorriso image for overwriteables
         in their first session would get a TOC of that first image rather
-        than of the media.
+        than of the medium.
         It is not possible to distinguish a BD-RE from a single session
-        BD-R with an image for overwriteables. But as soon as the media
+        BD-R with an image for overwriteables. But as soon as the medium
         bears 2 logical tracks it cannot be overwriteable.
         So count the number of tracks first.
      */
@@ -450,7 +450,7 @@ static int isoburn_welcome_media(struct isoburn **o, struct burn_drive *d,
        isoburn_toc_disc_free(disc);
      }
 
-     sprintf(msg, "ROM media has libburn track count = %d", track_count);
+     sprintf(msg, "ROM medium has libburn track count = %d", track_count);
      isoburn_msgs_submit(*o, 0x00060000, msg, 0, "DEBUG", 0);
 
      if((flag & 16) || track_count >= 2) {
@@ -525,6 +525,7 @@ ex:
                 bit5= ignore ACL from external filesystems
                 bit6= ignore POSIX Extended Attributes from external filesystems
                 bit7= pretend -ROM profile and scan for table of content
+                bit8= re-assess (*drive_infos)[0] rather than aquiring adr
 */
 int isoburn_drive_aquire(struct burn_drive_info *drive_infos[],
                          char *adr, int flag)
@@ -543,7 +544,10 @@ int isoburn_drive_aquire(struct burn_drive_info *drive_infos[],
  if(conv_ret<=0)
    strcpy(libburn_drive_adr, adr);
 
- ret= burn_drive_scan_and_grab(drive_infos, libburn_drive_adr, flag&1);
+ if(flag & 256)
+   ret= burn_drive_re_assess((*drive_infos)[0].drive, 0);
+ else
+   ret= burn_drive_scan_and_grab(drive_infos, libburn_drive_adr, flag&1);
  if(ret<=0)
    goto ex;
  drive_grabbed= 1;
@@ -601,8 +605,8 @@ ex:
 }
 
 
-/** Retrieve media emulation and eventual isoburn emulator of drive.
-    @return -1 unsuitable media, 0 generic media, 1 emulated media.
+/** Retrieve medium emulation and eventual isoburn emulator of drive.
+    @return -1 unsuitable medium, 0 generic medium, 1 emulated medium.
 */
 int isoburn_find_emulator(struct isoburn **pt,
                                  struct burn_drive *drive, int flag)
@@ -614,7 +618,7 @@ int isoburn_find_emulator(struct isoburn **pt,
    return(0);
  if((*pt)->emulation_mode==-1) {
    isoburn_msgs_submit(*pt, 0x00060000,
-                    "Unsuitable drive and media state", 0, "FAILURE", 0);
+                    "Unsuitable drive and medium state", 0, "FAILURE", 0);
    return(-1);
  }
  if((*pt)->emulation_mode==0)
@@ -760,7 +764,7 @@ int isoburn_disc_get_msc1(struct burn_drive *d, int *start_lba)
  if(isoburn_disc_get_status(d)!=BURN_DISC_APPENDABLE &&
     isoburn_disc_get_status(d)!=BURN_DISC_FULL) {
    isoburn_msgs_submit(NULL, 0x00060000,
-                       "Media contains no recognizable data", 0, "SORRY", 0);
+                       "Medium contains no recognizable data", 0, "SORRY", 0);
    return(0);
  }
  ret= isoburn_find_emulator(&o, d, 0);
@@ -1342,7 +1346,7 @@ int isoburn_emulate_toc(struct burn_drive *d, int flag)
  if(msg == NULL || size_text == NULL)
    {ret= -1; goto ex;}
  
- /* is the media emulated multi-session ? */
+ /* is the medium emulated multi-session ? */
  ret= isoburn_find_emulator(&o, d, 0);
  if(ret<0)
    {ret= -1; goto ex;}
@@ -1374,7 +1378,7 @@ int isoburn_emulate_toc(struct burn_drive *d, int flag)
    with_enclosure= 1;
    if((flag & 16) && o->emulation_mode == 1) {
      ret= 1;
-     goto failure; /* This will represent the media as single session */
+     goto failure; /* This will represent the medium as single session */
    }
  }
  while(lba<image_size || (flag&2)) {
@@ -1570,7 +1574,7 @@ struct isoburn_toc_disc *isoburn_toc_drive_get_disc(struct burn_drive *d)
  toc_disc->track_count= 0;
  toc_disc->toc= NULL; 
 
- /* is the media emulated multi-session ? */
+ /* is the medium emulated multi-session ? */
  ret= isoburn_find_emulator(&o, d, 0);
  if(ret<0)
    goto libburn;
