@@ -69,9 +69,9 @@ struct isoburn {
     Most isoburn calls will use a burn_drive as object handle */
  struct burn_drive *drive;
 
- /* -1= inappropriate media state detected
-    0= libburn multi-session media, resp. undecided yet
-    1= random access media */
+ /* -1= inappropriate medium state detected
+    0= libburn multi-session medium, resp. undecided yet
+    1= random access medium */
  int emulation_mode;
 
  /* Although rarely used, libburn can operate on several
@@ -215,7 +215,7 @@ int isoburn_invalidate_iso(struct isoburn *o, int flag);
                  with no emulation activated by isoburn.
     @param drive The drive to be searched for
     @param flag  unused yet
-    @return -1 unsuitable media, 0 generic media, 1 emulated media.
+    @return -1 unsuitable medium, 0 generic medium, 1 emulated medium.
 */
 int isoburn_find_emulator(struct isoburn **pt,
                           struct burn_drive *drive, int flag);
@@ -227,7 +227,7 @@ int isoburn_msgs_submit(struct isoburn *o, int error_code, char msg_text[],
                         int os_errno, char severity[], int flag);
 
 /** Set the start address for an emulated add-on session. The value will
-    be rounded up to the alignment necessary for the media. The aligned
+    be rounded up to the alignment necessary for the medium. The aligned
     value will be divided by 2048 and then put into  o->nwa .
     @param o     The isoburn object to be programmed.
     @param value The start address in bytes
@@ -543,7 +543,7 @@ struct isoburn_imgen_opts {
     int fifo_size;
 
 
-    /** Output value: Block address of session start as evaluated from media
+    /** Output value: Block address of session start as evaluated from medium
                       and other options by libisoburn and libburn.
         If <0 : Invalid
         If >=0: Valid block number. Block size is always 2 KiB.
@@ -652,7 +652,7 @@ struct isoburn_imgen_opts {
    Libisoburn_nwa_alignemenT it should be possible to predict the start
    of the next session header.
    The LBA 0 header is written by isoburn_activate_session() already
-   with the first session. So the media is mountable.
+   with the first session. So the medium is mountable.
    A problem arises with DVD-RW in Intermediate State. They cannot be
    written by random access before they were written sequentially.
    In this case, no copy of the session  1 header is maintained and no TOC
