@@ -492,7 +492,7 @@ int isoburn_start_emulation(struct isoburn *o, int flag)
  ret = burn_get_read_capacity(drive, &capacity, 0);
  if (ret <= 0)
    capacity = -1;
- if (role == 5) { /* random access write-only media */
+ if (role == 5) { /* random access write-only medium */
    s = burn_disc_get_status(drive);
    o->fabricated_disc_status= s;
    burn_disc_track_lba_nwa(drive, NULL, 0, &dummy, &(o->nwa));
@@ -524,7 +524,7 @@ int isoburn_start_emulation(struct isoburn *o, int flag)
      {ret= 1; goto ex;}
    }
  } else {
-   /* No read capacity means blank media */
+   /* No read capacity means blank medium */
    if(!(flag & 1))
      o->fabricated_disc_status= BURN_DISC_BLANK;
    {ret= 1; goto ex;}
@@ -587,9 +587,9 @@ ex:;
 }
 
 
-/** Alters and writes the first 64 kB of a "media" to invalidate
+/** Alters and writes the first 64 kB of a "medium" to invalidate
     an ISO image. (It shall stay restorable by skilled humans, though).
-    The result shall especially keep libisoburn from accepting the media
+    The result shall especially keep libisoburn from accepting the medium
     image as ISO filesystem.
     @param o A fully activated isoburn object. isoburn_start_emulation()
              was already called.
