@@ -1,7 +1,7 @@
 
 /* xorriso - creates, loads, manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2010 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2011 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -920,7 +920,7 @@ ex:;
 int Xorriso_rmx(struct XorrisO *xorriso, off_t boss_mem, char *path, int flag)
 {
  int ret, is_dir= 0, made_accessible= 0;
- struct stat victim_stbuf, *victim_node= NULL;
+ struct stat victim_stbuf;
  struct DirseQ *dirseq= NULL;
  char *sfe= NULL, *sub_path= NULL;
  struct PermiteM *perm_stack_mem;
@@ -959,7 +959,6 @@ int Xorriso_rmx(struct XorrisO *xorriso, off_t boss_mem, char *path, int flag)
    Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
    {ret= 0; goto ex;}
  }
- victim_node= &victim_stbuf;
  if(S_ISDIR(victim_stbuf.st_mode))
    is_dir= 1;
  if(!is_dir) {
@@ -974,6 +973,10 @@ int Xorriso_rmx(struct XorrisO *xorriso, off_t boss_mem, char *path, int flag)
 
 #ifdef Osirrox_not_yeT
      /* >>> */
+    
+     struct stat *victim_node= NULL;
+
+     victim_node= &victim_stbuf;
 
      if((xorriso->do_reassure==1 && !xorriso->request_not_to_ask) ||
         (flag&32)) {
@@ -1209,6 +1212,8 @@ int Xorriso_findx_action(struct XorrisO *xorriso, struct FindjoB *job,
    if(ret != -1)
      ret= Xorriso_estimate_file_size(xorriso, job, basename, stbuf.st_mode,
                                      stbuf.st_size, 0);
+ } else if(action == 44) { /* list_extattr */
+   ret= Xorriso_list_extattr(xorriso, NULL, abs_path, show_path, target, 2);
  } else {
    Text_shellsafe(show_path, xorriso->result_line, 0);
    strcat(xorriso->result_line, "\n");
@@ -1405,12 +1410,12 @@ int Xorriso_restore_sorted(struct XorrisO *xorriso, int count,
      /* sort_lba : Make directories plus node_array and then
                    run array extractor (with eventual hardlink detection)
      */
-     hflag= (1 << 7) | ((!!(flag & 2)) << 9);
+     hflag= (1 << 7) | ((!!(flag & 2)) << 9) | (flag & 32);
      ret= Xorriso_restore(xorriso, src_array[i], tgt_array[i],
                           (off_t) 0, (off_t) 0, hflag);
      if(ret <= 0) {
        (*problem_count)++;
-       hret= Xorriso_eval_problem_status(xorriso, ret, 0);
+       hret= Xorriso_eval_problem_status(xorriso, ret, 1 | 2);
        if(hret < 0)
          goto ex;
      }
@@ -1430,10 +1435,10 @@ int Xorriso_restore_sorted(struct XorrisO *xorriso, int count,
      if(src_array[i] == NULL || tgt_array[i] == NULL)
    continue;
      ret= Xorriso_restore(xorriso, src_array[i], tgt_array[i],
-                          (off_t) 0, (off_t) 0, 2 << 7);
+                          (off_t) 0, (off_t) 0, (2 << 7) | (flag & 32));
      if(ret <= 0) {
        (*problem_count)++;
-       hret= Xorriso_eval_problem_status(xorriso, ret, 0);
+       hret= Xorriso_eval_problem_status(xorriso, ret, 1 | 2);
        if(hret < 0)
          goto ex;
      }
@@ -1450,11 +1455,11 @@ int Xorriso_restore_sorted(struct XorrisO *xorriso, int count,
      if(src_array[i] == NULL || tgt_array[i] == NULL)
    continue;
      ret= Xorriso_restore(xorriso, src_array[i], tgt_array[i],
-                          (off_t) 0, (off_t) 0, 0);
+                          (off_t) 0, (off_t) 0, flag & 32);
      if(ret <= 0) {
        (*problem_count)++;
-       hret= Xorriso_eval_problem_status(xorriso, ret, flag & 32);
-       if(ret < 0)
+       hret= Xorriso_eval_problem_status(xorriso, ret, 1 | 2);
+       if(hret < 0)
          goto ex;
      }
    }
