@@ -160,6 +160,9 @@ ex:;
                      the write start address
                bit5= do not print toc
                bit6= do not calm down drive after aquiring it
+               bit7= re-assess rather than aquire:
+                     Do not give up drives,
+                     use isoburn_drive_aquire() with re-assessment bit
    @return <=0 failure , 1= ok
            2=success, but not writeable with bit1
            3=success, but not blank and not ISO with bit0
@@ -170,8 +173,8 @@ int Xorriso_aquire_drive(struct XorrisO *xorriso, char *adr, char *show_adr,
  int ret, hret, not_writeable= 0, has_what, aquire_flag, load_lba, ext;
  int lba, track, session, params_flag, adr_mode, read_ret;
  uint32_t size, offst;
- struct burn_drive_info *dinfo= NULL, *out_dinfo, *in_dinfo;
- struct burn_drive *drive= NULL, *out_drive, *in_drive;
+ struct burn_drive_info *dinfo= NULL, *out_dinfo= NULL, *in_dinfo= NULL;
+ struct burn_drive *drive= NULL, *out_drive= NULL, *in_drive= NULL;
  enum burn_disc_status state;
  IsoImage *volset = NULL;
  IsoNode *root_node;
@@ -199,9 +202,11 @@ int Xorriso_aquire_drive(struct XorrisO *xorriso, char *adr, char *show_adr,
    Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FATAL", 0);
    {ret= -1; goto ex;}
  }
- ret= Xorriso_give_up_drive(xorriso, (flag&3)|8);
- if(ret<=0)
-   goto ex;
+ if(!(flag & 128)) {
+   ret= Xorriso_give_up_drive(xorriso, (flag&3)|8);
+   if(ret<=0)
+     goto ex;
+ }
  if(flag & 1) 
    xorriso->isofs_st_out= time(0) - 1;
 
@@ -219,7 +224,30 @@ int Xorriso_aquire_drive(struct XorrisO *xorriso, char *adr, char *show_adr,
    }
  }
 
- if((flag&3)==1 && xorriso->out_drive_handle!=NULL) {
+ if(flag & 128) {
+   if(flag & 1)
+     Xorriso_get_drive_handles(xorriso, &in_dinfo, &in_drive, "", 16);
+   if(flag & 2)
+     Xorriso_get_drive_handles(xorriso, &out_dinfo, &out_drive, "", 2 | 16);
+   if(in_dinfo != NULL && (out_dinfo == NULL || out_dinfo == in_dinfo)) {
+     dinfo= in_dinfo;
+     if(flag & 2)
+       xorriso->outdev_is_exclusive= xorriso->indev_is_exclusive;
+   } else if(out_dinfo != NULL && in_dinfo == NULL) {
+     dinfo= out_dinfo;
+     if(flag & 1)
+       xorriso->indev_is_exclusive= xorriso->outdev_is_exclusive;
+   } else if(out_dinfo != NULL || in_dinfo != NULL) {
+     sprintf(xorriso->info_text,
+             "Two different drives shall be re-assed in one call");
+     Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FATAL", 0);
+     {ret= 0; goto ex;}
+   } else {
+     sprintf(xorriso->info_text, "No drive aquired on re-assessment");
+     Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FATAL", 0);
+     {ret= 0; goto ex;}
+   }
+ } else if((flag&3)==1 && xorriso->out_drive_handle!=NULL) {
    ret= Xorriso_get_drive_handles(xorriso, &out_dinfo, &out_drive,
                          "on attempt to compare new indev with outdev", 2);
    if(ret<=0)
@@ -241,7 +269,7 @@ int Xorriso_aquire_drive(struct XorrisO *xorriso, char *adr, char *show_adr,
    }
  }
 
- if(dinfo==NULL) {
+ if(dinfo == NULL || (flag & 128)) {
    aquire_flag= 1 | ((flag&(8|4))>>1) | ((xorriso->toc_emulation_flag & 3)<<3);
    if(xorriso->toc_emulation_flag & 4)
      aquire_flag|= 128;
@@ -249,17 +277,21 @@ int Xorriso_aquire_drive(struct XorrisO *xorriso, char *adr, char *show_adr,
      aquire_flag|= 32;
    if((xorriso->ino_behavior & (1 | 2)) && !(xorriso->do_aaip & (4 | 32)))
      aquire_flag|= 64;
+   if(flag & 128)
+     aquire_flag|= 256;
    burn_preset_device_open(xorriso->drives_exclusive, 0, 0);
    burn_allow_drive_role_4(1 | (xorriso->early_stdio_test & 14));
    ret= isoburn_drive_aquire(&dinfo, libburn_adr, aquire_flag);
    burn_preset_device_open(1, 0, 0);
    Xorriso_process_msg_queues(xorriso,0);
    if(ret<=0) {
-     sprintf(xorriso->info_text,"Cannot aquire drive '%s'", adr); 
+     if(flag & 128)
+       sprintf(xorriso->info_text,"Cannot re-assess drive '%s'", adr); 
+     else
+       sprintf(xorriso->info_text,"Cannot aquire drive '%s'", adr); 
      Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
      ret= 0; goto ex;
    }
-
    state= isoburn_disc_get_status(dinfo[0].drive);
    ret= isoburn_get_img_partition_offset(dinfo[0].drive, &offst);
    if((state == BURN_DISC_APPENDABLE || state == BURN_DISC_FULL) && ret == 1) {
@@ -596,7 +628,7 @@ int Xorriso_give_up_drive(struct XorrisO *xorriso, int flag)
      do_eject= !!(flag&4);
      if((flag & 4) && !xorriso->indev_is_exclusive) {
        sprintf(xorriso->info_text,
-               "Will not eject media in non-exclusively aquired input drive.");
+              "Will not eject medium in non-exclusively aquired input drive.");
        Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "WARNING", 0);
        do_eject= 0;
      }
@@ -628,7 +660,7 @@ int Xorriso_give_up_drive(struct XorrisO *xorriso, int flag)
    do_eject= !!(flag&4);
    if((flag & 4) && !xorriso->outdev_is_exclusive) {
      sprintf(xorriso->info_text,
-             "Will not eject media in non-exclusively aquired drive.");
+             "Will not eject medium in non-exclusively aquired drive.");
      Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "WARNING", 0);
      do_eject= 0;
    }
@@ -709,8 +741,11 @@ ex:;
 }
 
 
-/* @param flag bit0+1= what to give up and re-aquire by the address of outdev
-                       0=none, 1=indev, 2=outdev, 3=both
+/* @param flag bit0+1= what to give up and/or re-assess in what role
+                       0=give up outdev
+                       1=give up indev if not outdev, re-assess outdev as indev
+                       2=re-assess outdev as outdev
+                       3=give up indev if not outdev, re-assess outdev as dev
 */
 int Xorriso_reaquire_outdev(struct XorrisO *xorriso, int flag)
 {
@@ -725,14 +760,20 @@ int Xorriso_reaquire_outdev(struct XorrisO *xorriso, int flag)
    strcpy(off_name, xorriso->outdev_off_adr);
  else
    strcpy(off_name, drive_name);
- Xorriso_give_up_drive(xorriso, aq_flag);
- if(aq_flag==0) { 
+
+ if(aq_flag == 0) {
+   Xorriso_give_up_drive(xorriso, 2);
    sprintf(xorriso->info_text,"Gave up -outdev ");
-   Text_shellsafe(xorriso->outdev, xorriso->info_text, 1);
+   Text_shellsafe(xorriso->indev, xorriso->info_text, 1);
    Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "NOTE", 0);
    {ret= 1; goto ex;}
  }
- sprintf(xorriso->info_text,"Re-aquiring -outdev ");
+
+ /* Only give up indev, and only if it is not outdev */;
+ if(xorriso->in_drive_handle != xorriso->out_drive_handle &&
+    xorriso->in_drive_handle != NULL && (aq_flag & 1))
+   Xorriso_give_up_drive(xorriso, 1 | 8);
+ sprintf(xorriso->info_text,"Re-assessing -outdev ");
  Text_shellsafe(drive_name, xorriso->info_text, 1);
  if(strcmp(drive_name, off_name) != 0) {
    strcat(xorriso->info_text, "  (");
@@ -740,16 +781,16 @@ int Xorriso_reaquire_outdev(struct XorrisO *xorriso, int flag)
    strcat(xorriso->info_text, ")");
  }
  Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "NOTE", 0);
- ret= Xorriso_aquire_drive(xorriso, off_name, drive_name, aq_flag); 
+
+ /* Re-assess outdev */
+ ret= Xorriso_aquire_drive(xorriso, off_name, drive_name, aq_flag | 128); 
  if(ret<=0) {
-   sprintf(xorriso->info_text,"Could not re-aquire -outdev ");
+   sprintf(xorriso->info_text,"Could not re-assess -outdev ");
    Text_shellsafe(drive_name, xorriso->info_text, 1);
    Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
    goto ex;
  }
- strcpy(xorriso->outdev, drive_name);
- if(strcmp(xorriso->outdev, xorriso->indev) == 0)
-   strcpy(xorriso->indev, drive_name);
+
  ret= 1;
 ex:;
  Xorriso_free_meM(drive_name);
@@ -845,7 +886,7 @@ int Xorriso_toc(struct XorrisO *xorriso, int flag)
  struct burn_multi_caps *caps= NULL;
  struct burn_drive *drive;
  enum burn_disc_status s;
- char mem_text[80];
+ char mem_text[80], *num_free_text;
  off_t start_byte= 0, num_free= 0, size;
  unsigned dummy;
  struct isoburn_toc_disc *disc= NULL;
@@ -856,6 +897,7 @@ int Xorriso_toc(struct XorrisO *xorriso, int flag)
  struct burn_toc_entry next_toc_entry;
  int disk_category, part_version, num_layers, num_blocks;
  char *book_name;
+ int num_data_from_format= 0;
 /*
  int num_payload= 0, num_wasted= 0, num_nondata= 0;
 */
@@ -1000,8 +1042,12 @@ int Xorriso_toc(struct XorrisO *xorriso, int flag)
        lba= num_blocks;
    }
 
-   sprintf(respt, "Media blocks : %d readable , %d writable , %d overall\n",
-                  num_data, (int) num_free, lba);
+   if(drive_role == 4)
+     num_free_text = "unused";
+   else
+     num_free_text = "writable";
+   sprintf(respt, "Media blocks : %d readable , %d %s , %d overall\n",
+                  num_data, (int) num_free, num_free_text, lba);
    Xorriso_toc_line(xorriso, flag & 8);
  }
 
@@ -1069,6 +1115,8 @@ int Xorriso_toc(struct XorrisO *xorriso, int flag)
        ret= burn_get_read_capacity(drive, &num_data, 0);
        if(ret == 1)
          size= ((off_t) num_data) * (off_t) 2048; 
+     } else {
+       num_data_from_format= 1;
      }
      nwa= lba + size / 2048;
      num_data= nwa - lba;
@@ -1182,7 +1230,10 @@ int Xorriso_toc(struct XorrisO *xorriso, int flag)
  Sfile_scale(((double) num_data) * 2048.0, mem_text,5,1e4,1);
  sprintf(respt, "Media summary: %d session%s, %d data blocks, %s data",
          num_sessions, (num_sessions==1 ? "" : "s"), num_data, mem_text);
- num_free= isoburn_disc_available_space(drive, NULL); 
+ if(num_data_from_format)
+   num_free= 0;
+ else
+   num_free= isoburn_disc_available_space(drive, NULL); 
  Sfile_scale((double) num_free, mem_text,5,1e4,1);
  sprintf(respt+strlen(respt), ", %s free", mem_text);
 
@@ -1199,7 +1250,7 @@ int Xorriso_toc(struct XorrisO *xorriso, int flag)
  }
  if(profile_no == 0x41 && num_sessions >= 300) { 
    sprintf(xorriso->info_text,
-           "Sequential BD-R media now contains %d sessions. It is likely to soon fail writing.",
+           "Sequential BD-R medi/m now contains %d sessions. It is likely to soon fail writing.",
            num_sessions);
    Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "WARNING", 0);
  }
@@ -1236,7 +1287,7 @@ int Xorriso_show_devices(struct XorrisO *xorriso, int flag)
    usleep(100000);
  }
  Xorriso_process_msg_queues(xorriso,0);
- if(drive_count <= 0) {
+ if(drive_count == 0) {
 
    /* >>> was a drive_list created at all ? */
    /* >>> must it be freed ? */
@@ -1623,6 +1674,8 @@ int Xorriso_list_profiles(struct XorrisO *xorriso, int flag)
 int Xorriso_atip(struct XorrisO *xorriso, int flag)
 {
  int ret, profile_number= 0;
+ int num_profiles= 0, profiles[64], i, can_write= 0, pf, no_medium= 0;
+ char is_current[64];
  char *respt, profile_name[80];
  double x_speed_max, x_speed_min= -1.0;
  struct burn_drive_info *dinfo;
@@ -1662,9 +1715,29 @@ int Xorriso_atip(struct XorrisO *xorriso, int flag)
  Xorriso_result(xorriso,1);
  if(flag&1)
    return(1);
- sprintf(respt, "Driver flags   : BURNFREE\n");
- sprintf(respt+strlen(respt), "Supported modes: SAO TAO\n");
- Xorriso_result(xorriso,1);
+
+ /* Do not report "Supported modes: SAO TAO" with -ROM drives */
+ burn_drive_get_all_profiles(drive, &num_profiles, profiles, is_current);
+ if(num_profiles > 0) {
+   for(i= 0; i < num_profiles; i++) {
+     pf= profiles[i];
+     if(pf == 0x09 || pf == 0x0a || pf == 0x11 || pf == 0x12 || pf == 0x13 ||
+        pf == 0x14 || pf == 0x15 || pf == 0x1a || pf == 0x1b || pf == 0x2b ||
+        pf == 0x41 || pf == 0x43 || pf == 0xffff) {
+       can_write= 1;
+   break;
+     }
+   }
+ } else
+   can_write= 1;
+ if(can_write) {
+   sprintf(respt, "Driver flags   : BURNFREE\n");
+   sprintf(respt+strlen(respt), "Supported modes: SAO TAO\n");
+   Xorriso_result(xorriso,1);
+ } else if(flag & 2) {
+   sprintf(xorriso->info_text, "Not a CD/DVD/BD recorder");
+   Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "SORRY", 0);
+ }
  if(flag&2)
    return(1);
 
@@ -1684,11 +1757,15 @@ int Xorriso_atip(struct XorrisO *xorriso, int flag)
  if(s==BURN_DISC_EMPTY) {
    sprintf(respt, "Current: none\n");
    Xorriso_result(xorriso,1);
-   return(1);
+   sprintf(xorriso->info_text, "No recognizable medium found in drive");
+   Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "SORRY", 0);
+   no_medium= 1;
  } else 
    sprintf(respt, "Current: %s\n",profile_name);
  Xorriso_result(xorriso,1);
  Xorriso_list_profiles(xorriso, 1 | 2);
+ if(no_medium)
+   return(1);
  if(strstr(profile_name,"BD")==profile_name) {
    printf("Mounted Media: %2.2Xh, %s\n", profile_number, profile_name);
  } else if(strstr(profile_name,"DVD")==profile_name) {
@@ -1833,7 +1910,7 @@ int Xorriso_msinfo(struct XorrisO *xorriso, int *msc1, int *msc2, int flag)
    Xorriso_process_msg_queues(xorriso,0);
    if(!(flag & 4)) {
      sprintf(xorriso->info_text,
-             "%s media is not appendable. Cannot obtain -msinfo.",
+             "%s medium is not appendable. Cannot obtain -msinfo.",
              (flag&2) ? "Output" : "Input");
      Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
    }
@@ -2413,7 +2490,7 @@ int Xorriso_check_media(struct XorrisO *xorriso, struct SpotlisT **spotlist,
  if(ret<=0)
    goto ex;
  
- /* >>> determine media type dependent blocking factor:
+ /* >>> determine medium type dependent blocking factor:
         32 kB for CD (with 2kB retry) and DVD, 64 kB for BD
         eventually adjust read_chunk
  */;
@@ -2554,7 +2631,7 @@ int Xorriso_check_media(struct XorrisO *xorriso, struct SpotlisT **spotlist,
      goto ex;
  } else if(mode == 2) {
 libburn_whole_disc:;
-   /* single sweep over libburn media capacity */
+   /* single sweep over libburn medium capacity */
    ret= burn_get_read_capacity(drive, &blocks, 0);
    if(ret <= 0) {
      Xorriso_process_msg_queues(xorriso,0);
