@@ -29,6 +29,22 @@
 #include "xorrisoburn.h"
 
 
+int Xorriso_cdrskin_uses_stdout(struct XorrisO *xorriso, int argc, char **argv,
+                                int flag)
+{
+ int i;
+
+ for(i= 0; i < argc; i++) {
+   if(strcmp(argv[i], "dev=-") == 0 ||
+      strcmp(argv[i], "dev=stdio:/dev/fd/1") == 0 ||
+      strcmp(argv[i], "-dev=-") == 0 ||
+      strcmp(argv[i], "-dev=stdio:/dev/fd/1") == 0)
+     return(1);
+ }
+ return(0);
+}
+
+
 int Xorriso_cdrskin_help(struct XorrisO *xorriso, int flag)
 {
  static char helptext[][80]= {
@@ -39,8 +55,9 @@ int Xorriso_cdrskin_help(struct XorrisO *xorriso, int flag)
 "\t--devices\tprint list of available MMC drives and exit emulation",
 "\tdev=target\tpseudo-SCSI target to use as CD-Recorder",
 "\t-v\t\tincrement verbose level by one",
+"\t-V\t\tincrement SCSI command transport verbose level by one",
 "\t-checkdrive\tcheck if a driver for the drive is present",
-"\t-inq\t\tdo an inquiry for the drive and exit emulation",
+"\t-inq\t\tdo an inquiry for the drive",
 "\tspeed=#\t\tset speed of drive",
 "\tblank=type\tblank a CD-RW disc (see blank=help)",
 "\tfs=#\t\tSet fifo size to # (0 to disable, default is 4 MB)",
@@ -137,7 +154,7 @@ static char blank_help[][80]= {
 "\tdisk\t\tblank the entire disk",
 "\tfast\t\tminimally blank the entire disk",
 "\tminimal\t\tminimally blank the entire disk",
-"\tas_needed\tblank or format media to make it ready for (re-)use",
+"\tas_needed\tblank or format medium to make it ready for (re-)use",
 "\tdeformat\t\tblank a formatted DVD-RW",
 "\tdeformat_quickest\tminimally blank a formatted DVD-RW to DAO only",
 "\tformat_overwrite\tformat a DVD-RW to \"Restricted Overwrite\"",
