@@ -365,11 +365,13 @@ int Xorriso__sev_to_text(int severity, char **severity_name,
 int Xorriso__text_to_sev(char *severity_name, int *severity_number, int flag)
 {
  int ret= 1;
+ char severity[20];
 
- ret= iso_text_to_sev(severity_name, severity_number);
+ Xorriso__to_upper(severity_name, severity, (int) sizeof(severity), 0);
+ ret= iso_text_to_sev(severity, severity_number);
  if(ret>0)
    return(ret);
-   ret= burn_text_to_sev(severity_name, severity_number, 0);
+ ret= burn_text_to_sev(severity, severity_number, 0);
  return(ret);
 }
 
