@@ -1,7 +1,7 @@
 
 /* xorriso - creates, loads, manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2010 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2011 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -115,6 +115,16 @@ int Xorriso_option_list_delimiter(struct XorrisO *xorriso, char *text,
 }
 
 
+/* Option -list_extras */
+int Xorriso_option_list_extras(struct XorrisO *xorriso, char *mode, int flag)
+{
+ int ret;
+
+ ret= Xorriso_list_extras(xorriso, mode, 0);
+ return(ret);
+}
+
+
 /* Option -list_formats */
 int Xorriso_option_list_formats(struct XorrisO *xorriso, int flag)
 {
@@ -581,7 +591,7 @@ int Xorriso_option_map_l(struct XorrisO *xorriso, int argc, char **argv,
    if(ret>0 && !xorriso->request_to_abort)
  continue; /* regular bottom of loop */
    was_failure= 1;
-   fret= Xorriso_eval_problem_status(xorriso, ret, 2);
+   fret= Xorriso_eval_problem_status(xorriso, ret, 1 | 2);
    if(fret>=0)
  continue;
    goto ex;
@@ -1240,30 +1250,34 @@ int Xorriso_option_osirrox(struct XorrisO *xorriso, char *mode, int flag)
      l= npt-cpt;
    if(l==0 && mode[0]!=0)
      goto unknown_mode;
-   if(strncmp(cpt, "off", l)==0)
+   if(strncmp(cpt, "off", l)==0 && l >= 3)
      allow_restore= 0;
-   else if(strncmp(cpt, "banned", l)==0)
+   else if(strncmp(cpt, "banned", l)==0 && l >= 5)
      allow_restore= -1;
-   else if(strncmp(cpt, "device_files", l)==0)
+   else if(strncmp(cpt, "device_files", l)==0 && l >= 12)
      allow_restore= 2;
-   else if(strncmp(cpt, "on", l)==0 || mode[0]==0)
+   else if((strncmp(cpt, "on", l)==0 && l >= 2) || mode[0]==0)
      allow_restore= 1;
-   else if(strncmp(cpt, "concat_split_on", l)==0)
+   else if(strncmp(cpt, "concat_split_on", l)==0 && l >= 15)
      xorriso->do_concat_split= 1;
-   else if(strncmp(cpt, "concat_split_off", l)==0)
+   else if(strncmp(cpt, "concat_split_off", l)==0 && l >= 16)
      xorriso->do_concat_split= 0;
-   else if(strncmp(cpt, "auto_chmod_on", l)==0)
+   else if(strncmp(cpt, "auto_chmod_on", l)==0 && l >= 13)
      xorriso->do_auto_chmod= 1;
-   else if(strncmp(cpt, "auto_chmod_off", l)==0)
+   else if(strncmp(cpt, "auto_chmod_off", l)==0 && l >= 14)
      xorriso->do_auto_chmod= 0;
-   else if(strncmp(cpt, "sort_lba_on", l)==0)
+   else if(strncmp(cpt, "sort_lba_on", l)==0 && l >= 11)
      xorriso->do_restore_sort_lba= 1;
-   else if(strncmp(cpt, "sort_lba_off", l)==0)
+   else if(strncmp(cpt, "sort_lba_off", l)==0 && l >= 12)
      xorriso->do_restore_sort_lba= 0;
-   else if(strncmp(cpt, "o_excl_off", l)==0)
-     xorriso->drives_exclusive= 0;
-   else if(strncmp(cpt, "o_excl_on", l)==0)
+   else if(strncmp(cpt, "o_excl_on", l)==0 && l >= 9)
      xorriso->drives_exclusive= 1;
+   else if(strncmp(cpt, "o_excl_off", l)==0 && l >= 10)
+     xorriso->drives_exclusive= 0;
+   else if(strncmp(cpt, "strict_acl_on", l)==0 && l >= 13)
+     xorriso->do_strict_acl|= 1;
+   else if(strncmp(cpt, "strict_acl_off", l)==0 && l >= 14)
+     xorriso->do_strict_acl&= ~1;
    else {
 unknown_mode:;
      sprintf(xorriso->info_text, "-osirrox: unknown mode '%s'", cpt);
