@@ -270,6 +270,8 @@ struct XorrisO { /* the global context of xorriso */
  void *in_volset_handle; /* interpreted only by libburnia oriented modules */
  char *in_charset;       /* The charset to interpret the filename bytes */
  int indev_is_exclusive;
+ char indev_off_adr[SfileadrL]; /* Result of burn_drive_convert_fs_adr(indev)
+                                   when indev gets aquired. */
 
  time_t isofs_st_out;    /* A time point at least 1 second before image
                             composition began. To be stored with image as
@@ -296,6 +298,8 @@ struct XorrisO { /* the global context of xorriso */
                      connected to externaly perveived stdout.
                   */
  int outdev_is_exclusive;
+ char outdev_off_adr[SfileadrL]; /* Result of burn_drive_convert_fs_adr(outdev)
+		        	    when outdev gets aquired. */
 
  int grow_blindly_msc2; /* if >= 0 this causes growing from drive to drive.
                            The value is used as block address offset for
@@ -429,6 +433,10 @@ struct XorrisO { /* the global context of xorriso */
                                 tree traversal. Better read performance,
                                 no directory mtime restore, needs do_auto_chmod
                            */
+ int do_strict_acl;       /* bit0= do not tolerate inappropriate presence or
+                                   absence of directory "default" ACL
+                          */
+
  int mount_opts_flag; /* bit0= "shared" = not "exclusive"
                                Try to emit non-exclusive mount command.
                                Do not give up drives.
