@@ -19,7 +19,7 @@
 */
 #define xorriso_libisoburn_req_major  1
 #define xorriso_libisoburn_req_minor  1
-#define xorriso_libisoburn_req_micro  6
+#define xorriso_libisoburn_req_micro  8
 
 
 struct SpotlisT;          /* List of intervals with different read qualities */
@@ -76,8 +76,8 @@ int Xorriso_tell_media_space(struct XorrisO *xorriso,
                              int *media_space, int *free_space, int flag);
 
 /* @param flag bit0=fast , bit1=deformat
-   @return 0=failure, did not touch media , -1=failure, altered media
-           1=success, altered media       ,  2=success, did not touch media
+   @return 0=failure, did not touch medium , -1=failure, altered medium
+           1=success, altered medium       ,  2=success, did not touch medium
 */
 int Xorriso_blank_media(struct XorrisO *xorriso, int flag);
 
@@ -86,8 +86,8 @@ int Xorriso_blank_media(struct XorrisO *xorriso, int flag);
                bit2= do not re-aquire drive
                bit7= by_index mode:
                      bit8 to bit15 contain the index of the format to use.
-   @return 0=failure, did not touch media , -1=failure, altered media
-           1=success, altered media       ,  2=success, did not touch media
+   @return 0=failure, did not touch medium , -1=failure, altered medium
+           1=success, altered medium       ,  2=success, did not touch medium
 */
 int Xorriso_format_media(struct XorrisO *xorriso, off_t size, int flag);
 
@@ -105,8 +105,8 @@ int Xorriso_list_speeds(struct XorrisO *xorriso, int flag);
 int Xorriso_list_profiles(struct XorrisO *xorriso, int flag);
 
 /* @param flag bit2= formatting rather than blanking
-   @return 0=failure, did not touch media , -1=failure, altered media
-           1=success, altered media       ,  2=success, did not touch media
+   @return 0=failure, did not touch medium , -1=failure, altered medium
+           1=success, altered medium       ,  2=success, did not touch medium
 */ 
 int Xorriso_blank_as_needed(struct XorrisO *xorriso, int flag);
 
